@@ -45,6 +45,9 @@ class Page(object):
         else:
             self.page_title = self.name
 
+        self.base_title = self.page_title.split('/')[0]
+        self.base_name = self.name.split('/')[0]
+
         self.touched = parse_timestamp(info.get('touched'))
         self.revision = info.get('lastrevid', 0)
         self.exists = 'missing' not in info
@@ -64,10 +67,10 @@ class Page(object):
         self.edit_time = None
 
     def redirects_to(self):
-        """ Returns the redirect target page, or None if the page is not a redirect page."""
-        info = self.site.get('query', prop='pageprops', titles=self.name, redirects='')['query']
-        if 'redirects' in info:
-            for page in info['redirects']:
+        """ Get the redirect target page, or None if the page is not a redirect."""
+        info = self.site.get('query', prop='pageprops', titles=self.name, redirects='')
+        if 'redirects' in info['query']:
+            for page in info['query']['redirects']:
                 if page['from'] == self.name:
                     return Page(self.site, page['to'])
             return None
@@ -75,7 +78,7 @@ class Page(object):
             return None
 
     def resolve_redirect(self):
-        """ Returns the redirect target page, or the current page if it's not a redirect page."""
+        """ Get the redirect target page, or the current page if its not a redirect."""
         target_page = self.redirects_to()
         if target_page is None:
             return self
@@ -113,7 +116,7 @@ class Page(object):
             True
 
         """
-        level = self.protection.get(action, (action, ))[0]
+        level = self.protection.get(action, (action,))[0]
         if level == 'sysop':
             level = 'editprotected'
 
@@ -132,9 +135,9 @@ class Page(object):
         lives as long as the instance does.
 
         Args:
-            section (int): numbered section or `None` to get the whole page (default: `None`)
-            expandtemplates (bool): set to `True` to expand templates (default: `False`)
-            cache (bool): set to `False` to disable caching (default: `True`)
+            section (int): Section number, to only get text from a single section.
+            expandtemplates (bool): Expand templates (default: `False`)
+            cache (bool): Use in-memory caching (default: `True`)
         """
 
         if not self.can('read'):
@@ -148,7 +151,8 @@ class Page(object):
         if cache and key in self._textcache:
             return self._textcache[key]
 
-        revs = self.revisions(prop='content|timestamp', limit=1, section=section, slots=slot)
+        revs = self.revisions(prop='content|timestamp', limit=1, section=section,
+                              slots=slot)
         try:
             rev = next(revs)
             if 'slots' in rev:
@@ -162,17 +166,36 @@ class Page(object):
         if not expandtemplates:
             self.edit_time = time.gmtime()
         else:
-            # The 'rvexpandtemplates' option was removed in MediaWiki 1.32, so we have to make
-            # an extra API call. See: https://github.com/mwclient/mwclient/issues/214
+            # The 'rvexpandtemplates' option was removed in MediaWiki 1.32, so we have to
+            # make an extra API call, see https://github.com/mwclient/mwclient/issues/214
             text = self.site.expandtemplates(text)
 
         if cache:
             self._textcache[key] = text
         return text
 
-    def save(self, text, summary=u'', minor=False, bot=True, section=None, **kwargs):
+    def save(self, *args, **kwargs):
+        """Alias for edit, for maintaining backwards compatibility."""
+        return self.edit(*args, **kwargs)
+
+    def edit(self, text, summary=u'', minor=False, bot=True, section=None, **kwargs):
         """Update the text of a section or the whole page by performing an edit operation.
         """
+        return self._edit(summary, minor, bot, section, text=text, **kwargs)
+
+    def append(self, text, summary=u'', minor=False, bot=True, section=None,
+               **kwargs):
+        """Append text to a section or the whole page by performing an edit operation.
+        """
+        return self._edit(summary, minor, bot, section, appendtext=text, **kwargs)
+
+    def prepend(self, text, summary=u'', minor=False, bot=True, section=None,
+                **kwargs):
+        """Prepend text to a section or the whole page by performing an edit operation.
+        """
+        return self._edit(summary, minor, bot, section, prependtext=text, **kwargs)
+
+    def _edit(self, summary, minor, bot, section, **kwargs):
         if not self.site.logged_in and self.site.force_login:
             raise mwclient.errors.AssertUserFailedError()
         if self.site.blocked:
@@ -194,7 +217,7 @@ class Page(object):
             data['starttimestamp'] = time.strftime('%Y%m%d%H%M%S', self.edit_time)
         if bot:
             data['bot'] = '1'
-        if section:
+        if section is not None:
             data['section'] = section
 
         data.update(kwargs)
@@ -203,12 +226,13 @@ class Page(object):
             data['assert'] = 'user'
 
         def do_edit():
-            result = self.site.post('edit', title=self.name, text=text,
-                                    summary=summary, token=self.get_token('edit'),
+            result = self.site.post('edit', title=self.name, summary=summary,
+                                    token=self.get_token('edit'),
                                     **data)
             if result['edit'].get('result').lower() == 'failure':
                 raise mwclient.errors.EditError(self, result['edit'])
             return result
+
         try:
             result = do_edit()
         except mwclient.errors.APIError as e:
@@ -229,7 +253,8 @@ class Page(object):
         # Workaround for https://phabricator.wikimedia.org/T211233
         for cookie in self.site.connection.cookies:
             if 'PostEditRevision' in cookie.name:
-                self.site.connection.cookies.clear(cookie.domain, cookie.path, cookie.name)
+                self.site.connection.cookies.clear(cookie.domain, cookie.path,
+                                                   cookie.name)
 
         # clear the page text cache
         self._textcache = {}
@@ -249,6 +274,16 @@ class Page(object):
         else:
             raise e
 
+    def touch(self):
+        """Perform a "null edit" on the page to update the wiki's cached data of it.
+        This is useful in contrast to purge when needing to update stored data on a wiki,
+        for example Semantic MediaWiki properties or Cargo table values, since purge
+        only forces update of a page's displayed values and not its store.
+        """
+        if not self.exists:
+            return
+        self.append('')
+
     def move(self, new_title, reason='', move_talk=True, no_redirect=False):
         """Move (rename) page to new_title.
 
@@ -435,8 +470,8 @@ class Page(object):
         if generator:
             return mwclient.listing.PagePropertyGenerator(self, 'links', 'pl', **kwargs)
         else:
-            return mwclient.listing.PageProperty(self, 'links', 'pl', return_values='title',
-                                                 **kwargs)
+            return mwclient.listing.PageProperty(self, 'links', 'pl',
+                                                 return_values='title', **kwargs)
 
     def revisions(self, startid=None, endid=None, start=None, end=None,
                   dir='older', user=None, excludeuser=None, limit=50,
@@ -459,22 +494,21 @@ class Page(object):
             prop (str): Which properties to get for each revision,
                 default: 'ids|timestamp|flags|comment|user'
             expandtemplates (bool): Expand templates in rvprop=content output
-            section (int): If rvprop=content is set, only retrieve the contents of this section.
-            diffto (str): Revision ID to diff each revision to. Use "prev",
-                          "next" and "cur" for the previous, next and current
-                          revision respectively.
-            slots (str): The content slot (Mediawiki >= 1.32) to retrieve
-                content from.
-            uselang (str): Language to use for parsed edit comments and other
-                           localized messages.
+            section (int): Section number. If rvprop=content is set, only the contents
+                of this section will be retrieved.
+            diffto (str): Revision ID to diff each revision to. Use "prev", "next" and
+                "cur" for the previous, next and current revision respectively.
+            slots (str): The content slot (Mediawiki >= 1.32) to retrieve content from.
+            uselang (str): Language to use for parsed edit comments and other localized
+                messages.
 
         Returns:
             mwclient.listings.List: Revision iterator
         """
-        kwargs = dict(mwclient.listing.List.generate_kwargs('rv', startid=startid, endid=endid,
-                                                            start=start, end=end, user=user,
-                                                            excludeuser=excludeuser, diffto=diffto,
-                                                            slots=slots))
+        kwargs = dict(mwclient.listing.List.generate_kwargs(
+            'rv', startid=startid, endid=endid, start=start, end=end, user=user,
+            excludeuser=excludeuser, diffto=diffto, slots=slots
+        ))
 
         if self.site.version[:2] < (1, 32) and 'rvslots' in kwargs:
             # https://github.com/mwclient/mwclient/issues/199
