@@ -7,16 +7,13 @@ import logging
 import requests
 import responses
 import mock
+import json
 import mwclient
 from mwclient.page import Page
 from mwclient.client import Site
 from mwclient.listing import Category
 from mwclient.errors import APIError, AssertUserFailedError, ProtectedPageError, InvalidPageTitle
 
-try:
-    import json
-except ImportError:
-    import simplejson as json
 
 if __name__ == "__main__":
     print()
@@ -215,7 +212,7 @@ class TestPage(unittest.TestCase):
         # For now, mwclient will just raise an EditError.
         # <https://github.com/mwclient/mwclient/issues/33>
         with pytest.raises(mwclient.errors.EditError):
-            page.save('Some text')
+            page.edit('Some text')
 
 
 class TestPageApiArgs(unittest.TestCase):
@@ -303,7 +300,7 @@ class TestPageApiArgs(unittest.TestCase):
         self.site.api.return_value = {
             'edit': {'result': 'Ok'}
         }
-        self.page.save('Some text')
+        self.page.edit('Some text')
         args = self.get_last_api_call_args()
 
         assert args['assert'] == 'user'
@@ -318,7 +315,7 @@ class TestPageApiArgs(unittest.TestCase):
         self.site.api.return_value = {
             'edit': {'result': 'Ok'}
         }
-        self.page.save('Some text')
+        self.page.edit('Some text')
         args = self.get_last_api_call_args()
 
         assert 'assert' not in args
